==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>打開wifi</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>關閉wifi</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>大寫</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>小寫</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>打開數字鍵盤</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>關閉數字鍵盤</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>打開觸控板</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>關閉觸控板</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>觸控板切換</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn切換</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>開啟飛航模式</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>關閉飛航模式</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>平衡模式</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>省電模式</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>高性能模式</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>打開窗口特效</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>關閉窗口特效</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>打開窗口特效失敗</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>麥克風已關</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>麥克風已開</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>打開wifi</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>關閉wifi</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>大寫</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>小寫</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>打開數字鍵盤</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>關閉數字鍵盤</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>打開觸控板</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>關閉觸控板</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>觸控板切換</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn切換</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>開啟飛航模式</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>關閉飛航模式</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>平衡模式</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>省電模式</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>高性能模式</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>打開窗口特效</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>關閉窗口特效</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>打開窗口特效失敗</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>麥克風已關</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>麥克風已開</translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Camera off</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
